==> luna_lambda_tools-0.0.4.tar.gz: luna_lambda_tools-0.0.4/luna_lambda_tools/private/request.py <==
from typing import Any, final

from cow.errors.exception import VLException
from cow.pydantic.loaders import loadDataFromJson
from cow.web.request import VLRequest
from luna3.client import Client as _Client
from vlutils.structures.pydantic import BaseModel

from .exceptions import BaseLambdaException


class BaseStandaloneLambdaRequest(VLRequest):
    """Base lambda request"""

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.accountId = self.headers.get("Luna-Account-Id")
        self.userCtx = self.app.ctx.userCtx
        self._luna3Client: _Client = self.app.ctx.luna3Session.getClient(self.requestId)
        # hack to override lambda name for monitoring
        self.app.name = self.app.ctx.lambdaName

    @property
    def json(self) -> int | float | list | dict[str, Any]:
        """Get json from request"""
        return super().json

    def getBody(self) -> bytes:
        """Get body from request"""
        return super().body

    def _getFacesClientKwargs(self) -> dict:
        """Get faces clients kwargs"""
        return {"facesClient": self._luna3Client.lunaFaces, "accountId": self.accountId}

    def _getEventsClientKwargs(self) -> dict:
        """Get events clients kwargs"""
        return {"eventsClient": self._luna3Client.lunaEvents, "accountId": self.accountId}

    def _getLPMClientKwargs(self) -> dict:
        """Get lpn clients kwargs"""
        return {"lpmClient": self._luna3Client.lunaPythonMatcher, "accountId": self.accountId}

    def _getFacesSamplesClientKwargs(self) -> dict:
        """Get faces samples clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaFaceSamplesStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.faceSamplesStorage.bucket,
        }

    def _getBodySamplesClientKwargs(self) -> dict:
        """Get body samples clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaBodySamplesStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.bodySamplesStorage.bucket,
        }

    def _getImageOriginClientKwargs(self) -> dict:
        """Get image origin clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaImageOriginStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.imageOriginStorage.bucket,
        }

    def _getLRSClientKwargs(self) -> dict:
        """Get lrs clients kwargs"""
        return {"lrsClient": self._luna3Client.lunaRemoteSDK, "accountId": self.accountId}

    def _getSenderClientKwargs(self) -> dict:
        """Get sender clients kwargs"""
        return {"senderClient": self._luna3Client.lunaSender, "accountId": self.accountId}


class BaseHandlersRequest(BaseStandaloneLambdaRequest):
    """
    Handlers Lambda app request base
    """

    @final
    def getRequestData(self, pydanticModel: type[BaseModel]):
        """Get data from request"""
        try:
            return loadDataFromJson(super().json, pydanticModel)
        except VLException as e:
            exc = BaseLambdaException
            exc.errorText = str(e.error.asDict())
            exc.statusCode = 400
            raise exc

==> luna_lambda_tools-0.0.9.tar.gz: luna_lambda_tools-0.0.9/luna_lambda_tools/private/request.py <==
from typing import Any, final

from cow.errors.exception import VLException
from cow.pydantic.loaders import loadDataFromJson
from cow.web.request import VLRequest
from luna3.client import Client as _Client
from sanic import Sanic
from vlutils.structures.pydantic import BaseModel

from .exceptions import BaseLambdaException
from .monitoring import MonitoringPoint


class BaseLambdaRequest(VLRequest):
    """Base lambda request"""

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.accountId = self.headers.get("Luna-Account-Id")
        self.userCtx = self.app.ctx.userCtx
        self.app.name = self.app.ctx.lambdaName

    @property
    def json(self) -> int | float | list | dict[str, Any]:
        """Get json from request"""
        return super().json

    def getBody(self) -> bytes:
        """Get body from request"""
        return super().body

    def sendToMonitoring(self, points: list[MonitoringPoint]) -> None:
        """
        Send point to monitoring

        Args:
            points: points
        """
        if self.config.monitoring.sendData:
            self.app.ctx.monitoring.flushPoints(points)


class ClientsKwargsMixin:
    """Luna services clients kwargs mixin"""

    _luna3Client: _Client
    accountId: str
    app: Sanic

    def _getFacesClientKwargs(self) -> dict:
        """Get faces clients kwargs"""
        return {"facesClient": self._luna3Client.lunaFaces, "accountId": self.accountId}

    def _getEventsClientKwargs(self) -> dict:
        """Get events clients kwargs"""
        return {"eventsClient": self._luna3Client.lunaEvents, "accountId": self.accountId}

    def _getLPMClientKwargs(self) -> dict:
        """Get lpn clients kwargs"""
        return {"lpmClient": self._luna3Client.lunaPythonMatcher, "accountId": self.accountId}

    def _getFacesSamplesClientKwargs(self) -> dict:
        """Get faces samples clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaFaceSamplesStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.faceSamplesStorage.bucket,
        }

    def _getBodySamplesClientKwargs(self) -> dict:
        """Get body samples clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaBodySamplesStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.bodySamplesStorage.bucket,
        }

    def _getImageOriginClientKwargs(self) -> dict:
        """Get image origin clients kwargs"""
        return {
            "lisClient": self._luna3Client.lunaImageOriginStore,
            "accountId": self.accountId,
            "bucket": self.app.ctx.serviceConfig.imageOriginStorage.bucket,
        }

    def _getLRSClientKwargs(self) -> dict:
        """Get lrs clients kwargs"""
        return {"lrsClient": self._luna3Client.lunaRemoteSDK, "accountId": self.accountId}

    def _getSenderClientKwargs(self) -> dict:
        """Get sender clients kwargs"""
        return {"senderClient": self._luna3Client.lunaSender, "accountId": self.accountId}


class BaseStandaloneLambdaRequest(BaseLambdaRequest, ClientsKwargsMixin):
    """Base lambda request"""

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._luna3Client: _Client = self.app.ctx.luna3Session.getClient(self.requestId)

    def sendToMonitoring(self, points: list[MonitoringPoint]) -> None:
        """
        Send point to monitoring

        Args:
            points: points
        """
        if self.config.monitoring.sendData:
            self.app.ctx.monitoring.flushPoints(points)


class BaseHandlersRequest(BaseStandaloneLambdaRequest):
    """
    Handlers Lambda app request base
    """

    @final
    def getRequestData(self, pydanticModel: type[BaseModel]):
        """Get data from request"""
        try:
            return loadDataFromJson(super().json, pydanticModel)
        except VLException as e:
            exc = BaseLambdaException
            exc.errorText = str(e.error.asDict())
            exc.statusCode = 400
            raise exc
